Parse to and export from UUID own type, before dereferencing.
This also fixes wrong comment (Little Endian UUID is something else)
and should eliminate the direct strict types assignments.

Fixes: 43001c52b603 ("powerpc/papr_scm: Use ibm,unit-guid as the iset cookie")
Fixes: 259a948c4ba1 ("powerpc/pseries/scm: Use a specific endian format for 
storing uuid from the device tree")
Cc: Oliver O'Halloran <ooh...@gmail.com>
Cc: Aneesh Kumar K.V <aneesh.ku...@linux.ibm.com>
Signed-off-by: Andy Shevchenko <andriy.shevche...@linux.intel.com>
---
v2: added missed header (Vaibhav), updated comment (Aneesh),
    rewrite part of the commit message to avoid mentioning the Sparse
 arch/powerpc/platforms/pseries/papr_scm.c | 27 +++++++++++++++--------
 1 file changed, 18 insertions(+), 9 deletions(-)

diff --git a/arch/powerpc/platforms/pseries/papr_scm.c 
b/arch/powerpc/platforms/pseries/papr_scm.c
index e2b69cc3beaf..b43be41e8ff7 100644
--- a/arch/powerpc/platforms/pseries/papr_scm.c
+++ b/arch/powerpc/platforms/pseries/papr_scm.c
@@ -18,6 +18,7 @@
 #include <asm/plpar_wrappers.h>
 #include <asm/papr_pdsm.h>
 #include <asm/mce.h>
+#include <asm/unaligned.h>
 
 #define BIND_ANY_ADDR (~0ul)
 
@@ -1101,8 +1102,9 @@ static int papr_scm_probe(struct platform_device *pdev)
        u32 drc_index, metadata_size;
        u64 blocks, block_size;
        struct papr_scm_priv *p;
+       u8 uuid_raw[UUID_SIZE];
        const char *uuid_str;
-       u64 uuid[2];
+       uuid_t uuid;
        int rc;
 
        /* check we have all the required DT properties */
@@ -1145,16 +1147,23 @@ static int papr_scm_probe(struct platform_device *pdev)
        p->hcall_flush_required = of_property_read_bool(dn, 
"ibm,hcall-flush-required");
 
        /* We just need to ensure that set cookies are unique across */
-       uuid_parse(uuid_str, (uuid_t *) uuid);
+       uuid_parse(uuid_str, &uuid);
+
        /*
         * cookie1 and cookie2 are not really little endian
         * we store a little endian representation of the
         * uuid str so that we can compare this with the label
         * area cookie irrespective of the endian config with which
         * the kernel is built.
         */
-       p->nd_set.cookie1 = cpu_to_le64(uuid[0]);
-       p->nd_set.cookie2 = cpu_to_le64(uuid[1]);
+       export_uuid(uuid_raw, &uuid);
+       p->nd_set.cookie1 = get_unaligned_le64(&uuid_raw[0]);
+       p->nd_set.cookie2 = get_unaligned_le64(&uuid_raw[8]);
 
        /* might be zero */
        p->metadata_size = metadata_size;
@@ -1145,16 +1147,23 @@ static int papr_scm_probe(struct platform_device *pdev)
        /*
-        * cookie1 and cookie2 are not really little endian
-        * we store a little endian representation of the
-        * uuid str so that we can compare this with the label
-        * area cookie irrespective of the endian config with which
-        * the kernel is built.
+        * The cookie1 and cookie2 are not really little endian.
+        * We store a raw buffer representation of the
+        * uuid string so that we can compare this with the label
+        * area cookie irrespective of the endian configuration
+        * with which the kernel is built.
+        *
+        * Historically we stored the cookie in the below format.
+        * for a uuid string 72511b67-0b3b-42fd-8d1d-5be3cae8bcaa
+        *      cookie1 was 0xfd423b0b671b5172
+        *      cookie2 was 0xaabce8cae35b1d8d
         */
-- 
2.30.2

Reply via email to